package
Version:
v0.0.0-...-d5453b7
Opens a new window with list of versions in this module.
Published: Jul 1, 2019
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DateEnum struct {
Type string `json:"type"`
Options []string `json:"options"`
}
type FloatBetween struct {
Type string `json:"type"`
From float64 `json:"from"`
To float64 `json:"to"`
}
type FloatEnum struct {
Type string `json:"type"`
Options []float64 `json:"options"`
}
type IntegerBetween struct {
Type string `json:"type"`
From int `json:"from"`
To int `json:"to"`
}
type IntegerEnum struct {
Type string `json:"type"`
Options []int `json:"options"`
}
type RelationshipOneToMany struct {
Type string `json:"type"`
To string `json:"to"`
}
type RelationshipOneToOne struct {
Type string `json:"type"`
To string `json:"to"`
}
func TypeFor(fieldType, validationType string) Rule
type StringEnum struct {
Type string `json:"type"`
Options []string `json:"options"`
}
type StringPlain struct {
Type string `json:"type"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.