form

package
v0.0.0-...-d5453b7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 1, 2019 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Encode

func Encode(s interface{}) ([]byte, string, error)

Encode encodes the struct s to a multpart form returning the request body, the content type (including boundary) for the form or an error

Types

type File

type File struct {
	Name    string
	Content io.Reader
}

Jump to